from .load_records import Zone
from .main import DNSServer
from .version import VERSION

__all__ = 'DNSServer', 'Zone', '__version__'
__version__ = VERSION
